Menu class

Constructors

Properties

hashCode → int
The hash code for this object.
no setterinherited
items ↔ List<MenuItem>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getMenuItem(String key) → MenuItem?
getMenuItemById(int id) → MenuItem?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited