MenuItem class

Constructors

Properties

checked ↔ bool?
getter/setter pair
disabled ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
icon ↔ String?
MacOS https://developer.apple.com/sf-symbols/
getter/setter pair
id ↔ int
getter/setter pair
key ↔ String?
getter/setter pair
label ↔ String?
getter/setter pair
onClick ↔ void Function(MenuItem menuItem)?
getter/setter pair
onHighlight ↔ void Function(MenuItem menuItem)?
getter/setter pair
onLoseHighlight ↔ void Function(MenuItem menuItem)?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shortcutKey ↔ String?
getter/setter pair
shortcutModifiers ↔ ShortcutModifiers?
getter/setter pair
sublabel ↔ String?
getter/setter pair
getter/setter pair
toolTip ↔ String?
getter/setter pair
type ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited