ShortcutModifiers class

Constructors

ShortcutModifiers({bool shift = false, bool control = false, bool command = false, bool alt = false})

Properties

alt → bool
final
command → bool
final
control → bool
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shift → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toList() → List<String>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited